@@ -12,7 +12,7 @@ from abc import ABC, abstractmethod
 from collections.abc import Mapping
 from concurrent.futures import CancelledError
 from copy import copy
-from datetime import datetime
+from datetime import datetime, timedelta
 from itertools import chain
 from typing import (
     TYPE_CHECKING,
@@ -35,8 +35,6 @@ from typing import (
 )
 
 from cognite.client._api.datapoint_tasks import (
-    DPS_LIMIT,
-    DPS_LIMIT_AGG,
     BaseConcurrentTask,
     BaseDpsFetchSubtask,
     CustomDatapoints,
@@ -58,16 +56,27 @@ from cognite.client.data_classes.datapoints import (
 from cognite.client.exceptions import CogniteAPIError, CogniteNotFoundError
 from cognite.client.utils._auxiliary import (
     assert_type,
+    exactly_one_is_not_none,
     find_duplicates,
     import_legacy_protobuf,
     local_import,
     split_into_chunks,
     split_into_n_parts,
-    validate_user_input_dict_with_identifier,
 )
 from cognite.client.utils._concurrency import collect_exc_info_and_raise, execute_tasks, get_priority_executor
 from cognite.client.utils._identifier import Identifier, IdentifierSequence
-from cognite.client.utils._time import timestamp_to_ms
+from cognite.client.utils._time import (
+    _unit_in_days,
+    align_large_granularity,
+    get_granularity_multiplier_and_unit,
+    in_timedelta,
+    pandas_date_range_tz,
+    timestamp_to_ms,
+    to_fixed_utc_intervals,
+    to_pandas_freq,
+    validate_timezone,
+)
+from cognite.client.utils._validation import validate_user_input_dict_with_identifier
 
 if not import_legacy_protobuf():
     from cognite.client._proto.data_point_list_response_pb2 import DataPointListItem, DataPointListResponse
@@ -82,14 +91,11 @@ if TYPE_CHECKING:
 
     import pandas as pd
 
+    from cognite.client import CogniteClient
+    from cognite.client.config import ClientConfig
     from cognite.client.utils._priority_tpe import PriorityThreadPoolExecutor
 
 
-POST_DPS_OBJECTS_LIMIT = 10_000
-FETCH_TS_LIMIT = 100
-RETRIEVE_LATEST_LIMIT = 100
-
-
 TSQueryList = List[_SingleTSQueryBase]
 PoolSubtaskType = Tuple[int, float, float, BaseDpsFetchSubtask]
 
@@ -102,7 +108,12 @@ def select_dps_fetch_strategy(dps_client: DatapointsAPI, user_query: _Datapoints
     if max_workers < 1:  # Dps fetching does not use fn `execute_tasks_concurrently`, so we must check:
         raise RuntimeError(f"Invalid option for `{max_workers=}`. Must be at least 1")
 
-    all_queries = _SingleTSQueryValidator(user_query).validate_and_create_single_queries()
+    validator = _SingleTSQueryValidator(
+        user_query,
+        dps_limit_raw=dps_client._DPS_LIMIT_RAW,
+        dps_limit_agg=dps_client._DPS_LIMIT_AGG,
+    )
+    all_queries = validator.validate_and_create_single_queries()
     agg_queries, raw_queries = split_queries_into_raw_and_aggs(all_queries)
 
     # Running mode is decided based on how many time series are requested VS. number of workers:
@@ -174,7 +185,7 @@ class DpsFetchStrategy(ABC):
         return self.dps_client._do_request(
             json=payload,
             method="POST",
-            url_path=self.dps_client._RESOURCE_PATH + "/list",
+            url_path=f"{self.dps_client._RESOURCE_PATH}/list",
             accept="application/protobuf",
             timeout=self.dps_client._config.timeout,
         ).content
@@ -309,8 +320,8 @@ class ChunkingDpsFetcher(DpsFetchStrategy):
 
     Is used when the number of time series to fetch is larger than the number of `max_workers`. How many
     time series are chunked per request is dynamic and is decided by the overall number to fetch, their
-    individual number of datapoints and wheter or not raw- or aggregate datapoints are asked for since
-    they are independent in requests - as long as the total number of time series does not exceed FETCH_TS_LIMIT.
+    individual number of datapoints and whether raw- or aggregate datapoints are asked for since
+    they are independent in requests - as long as the total number of time series does not exceed `_FETCH_TS_LIMIT`.
     """
 
     def __init__(self, *args: Any) -> None:
@@ -384,13 +395,13 @@ class ChunkingDpsFetcher(DpsFetchStrategy):
         initial_query_limits: Dict[_SingleTSQueryBase, int] = {}
         initial_futures_dct: Dict[Future, Tuple[TSQueryList, TSQueryList]] = {}
         # Optimal queries uses the entire worker pool. We may be forced to use more (queue) when we
-        # can't fit all individual time series (maxes out at `FETCH_TS_LIMIT * max_workers`):
-        n_queries = max(self.max_workers, math.ceil(self.n_queries / FETCH_TS_LIMIT))
+        # can't fit all individual time series (maxes out at `_FETCH_TS_LIMIT * max_workers`):
+        n_queries = max(self.max_workers, math.ceil(self.n_queries / self.dps_client._FETCH_TS_LIMIT))
         splitter: Callable[[List[T]], Iterator[List[T]]] = functools.partial(split_into_n_parts, n=n_queries)
         for query_chunks in zip(splitter(self.agg_queries), splitter(self.raw_queries)):
             # Agg and raw limits are independent in the query, so we max out on both:
             items = []
-            for queries, max_lim in zip(query_chunks, [DPS_LIMIT_AGG, DPS_LIMIT]):
+            for queries, max_lim in zip(query_chunks, [self.dps_client._DPS_LIMIT_AGG, self.dps_client._DPS_LIMIT_RAW]):
                 maxed_limits = self._find_initial_query_limits([q.capped_limit for q in queries], max_lim)
                 initial_query_limits.update(chunk_query_limits := dict(zip(queries, maxed_limits)))
                 items.extend([{**q.to_payload(), "limit": lim} for q, lim in chunk_query_limits.items()])
@@ -456,12 +467,16 @@ class ChunkingDpsFetcher(DpsFetchStrategy):
         next_items: List[CustomDatapoints] = []
         next_subtasks: List[BaseDpsFetchSubtask] = []
         agg_pool, raw_pool = self.subtask_pools
-        for task_pool, request_max_limit, is_raw in zip(self.subtask_pools, (DPS_LIMIT_AGG, DPS_LIMIT), [False, True]):
+        for task_pool, request_max_limit, is_raw in zip(
+            self.subtask_pools,
+            (self.dps_client._DPS_LIMIT_AGG, self.dps_client._DPS_LIMIT_RAW),
+            [False, True],
+        ):
             if not task_pool:
                 continue
             limit_used = 0  # Dps limit for raw and agg is independent (in same query)
             while task_pool:
-                if len(next_items) + 1 > FETCH_TS_LIMIT:
+                if len(next_items) + 1 > self.dps_client._FETCH_TS_LIMIT:
                     # Hard limit on N ts, quit immediately (even if below dps limit):
                     priority = statistics.mean(task.priority for task in next_subtasks)
                     payload: DatapointsPayload = {"items": next_items}
@@ -491,7 +506,7 @@ class ChunkingDpsFetcher(DpsFetchStrategy):
         return None
 
     @staticmethod
-    def _decide_individual_query_limit(query: _SingleTSQueryBase, ts_task: BaseConcurrentTask) -> int:
+    def _decide_individual_query_limit(query: _SingleTSQueryBase, ts_task: BaseConcurrentTask, n_ts_limit: int) -> int:
         # For a better estimate, we use first ts of first batch instead of `query.start`:
         batch_start, batch_end = ts_task.start_ts_first_batch, ts_task.end_ts_first_batch
         est_remaining_dps = ts_task.n_dps_first_batch * (query.end - batch_end) / (batch_end - batch_start)
@@ -503,7 +518,7 @@ class ChunkingDpsFetcher(DpsFetchStrategy):
         for chunk_size in (1, 2, 4, 8, 16, 32):
             if est_remaining_dps > max_limit // chunk_size:
                 return max_limit // (2 * chunk_size)
-        return max_limit // FETCH_TS_LIMIT
+        return max_limit // n_ts_limit
 
     def _update_queries_with_new_chunking_limit(
         self, ts_task_lookup: Dict[_SingleTSQueryBase, BaseConcurrentTask]
@@ -518,7 +533,7 @@ class ChunkingDpsFetcher(DpsFetchStrategy):
         # Many tasks left, decide how we'll chunk'em by estimating which are dense (and need little to
         # no chunking), and which are not (...and may be grouped - and how "tightly"):
         for query, ts_task in remaining_tasks.items():
-            est_limit = self._decide_individual_query_limit(query, ts_task)
+            est_limit = self._decide_individual_query_limit(query, ts_task, self.dps_client._FETCH_TS_LIMIT)
             query.override_max_query_limit(est_limit)
 
         return list(remaining_tasks.values())
@@ -571,11 +586,16 @@ class ChunkingDpsFetcher(DpsFetchStrategy):
 class DatapointsAPI(APIClient):
     _RESOURCE_PATH = "/timeseries/data"
 
-    def __init__(self, *args: Any, **kwargs: Any) -> None:
-        super().__init__(*args, **kwargs)
-        self.synthetic = SyntheticDatapointsAPI(
-            self._config, api_version=self._api_version, cognite_client=self._cognite_client
-        )
+    def __init__(self, config: ClientConfig, api_version: Optional[str], cognite_client: CogniteClient) -> None:
+        super().__init__(config, api_version, cognite_client)
+        self.synthetic = SyntheticDatapointsAPI(config, api_version, cognite_client)
+        self._FETCH_TS_LIMIT = 100
+        self._DPS_LIMIT_AGG = 10_000
+        self._DPS_LIMIT_RAW = 100_000
+        self._DPS_INSERT_LIMIT = 100_000
+        self._RETRIEVE_LATEST_LIMIT = 100
+        self._POST_DPS_OBJECTS_LIMIT = 10_000
+        self._GRANULARITY_HOURS_LIMIT = 100_000
 
     def retrieve(
         self,
@@ -607,8 +627,8 @@ class DatapointsAPI(APIClient):
             aggregates (Union[str, List[str], None]): Single aggregate or list of aggregates to retrieve. Default: None (raw datapoints returned)
             granularity (str): The granularity to fetch aggregates at. e.g. '15s', '2h', '10d'. Default: None.
             limit (int): Maximum number of datapoints to return for each time series. Default: None (no limit)
-            include_outside_points (bool): Whether or not to include outside points. Not allowed when fetching aggregates. Default: False
-            ignore_unknown_ids (bool): Whether or not to ignore missing time series rather than raising an exception. Default: False
+            include_outside_points (bool): Whether to include outside points. Not allowed when fetching aggregates. Default: False
+            ignore_unknown_ids (bool): Whether to ignore missing time series rather than raising an exception. Default: False
 
         Returns:
             Union[None, Datapoints, DatapointsList]: A `Datapoints` object containing the requested data, or a `DatapointsList` if multiple time series were asked for (the ordering is ids first, then external_ids). If `ignore_unknown_ids` is `True`, a single time series is requested and it is not found, the function will return `None`.
@@ -788,8 +808,8 @@ class DatapointsAPI(APIClient):
             aggregates (Union[str, List[str], None]): Single aggregate or list of aggregates to retrieve. Default: None (raw datapoints returned)
             granularity (str): The granularity to fetch aggregates at. e.g. '15s', '2h', '10d'. Default: None.
             limit (int): Maximum number of datapoints to return for each time series. Default: None (no limit)
-            include_outside_points (bool): Whether or not to include outside points. Not allowed when fetching aggregates. Default: False
-            ignore_unknown_ids (bool): Whether or not to ignore missing time series rather than raising an exception. Default: False
+            include_outside_points (bool): Whether to include outside points. Not allowed when fetching aggregates. Default: False
+            ignore_unknown_ids (bool): Whether to ignore missing time series rather than raising an exception. Default: False
 
         Returns:
             Union[None, DatapointsArray, DatapointsArrayList]: A `DatapointsArray` object containing the requested data, or a `DatapointsArrayList` if multiple time series were asked for (the ordering is ids first, then external_ids). If `ignore_unknown_ids` is `True`, a single time series is requested and it is not found, the function will return `None`.
@@ -888,8 +908,8 @@ class DatapointsAPI(APIClient):
             aggregates (Union[str, List[str], None]): Single aggregate or list of aggregates to retrieve. Default: None (raw datapoints returned)
             granularity (str): The granularity to fetch aggregates at. e.g. '15s', '2h', '10d'. Default: None.
             limit (int): Maximum number of datapoints to return for each time series. Default: None (no limit)
-            include_outside_points (bool): Whether or not to include outside points. Not allowed when fetching aggregates. Default: False
-            ignore_unknown_ids (bool): Whether or not to ignore missing time series rather than raising an exception. Default: False
+            include_outside_points (bool): Whether to include outside points. Not allowed when fetching aggregates. Default: False
+            ignore_unknown_ids (bool): Whether to ignore missing time series rather than raising an exception. Default: False
             uniform_index (bool): If only querying aggregates AND a single granularity is used AND no limit is used, specifying `uniform_index=True` will return a dataframe with an
                 equidistant datetime index from the earliest `start` to the latest `end` (missing values will be NaNs). If these requirements are not met, a ValueError is raised. Default: False
             include_aggregate_name (bool): Include 'aggregate' in the column name, e.g. `my-ts|average`. Ignored for raw time series. Default: True
@@ -926,7 +946,7 @@ class DatapointsAPI(APIClient):
                 ...     end=datetime(2020, 12, 31, tzinfo=timezone.utc),
                 ...     uniform_index=True)
 
-            Get a pandas dataframe containing the 'average' aggregate for two time series using a 30 day granularity,
+            Get a pandas dataframe containing the 'average' aggregate for two time series using a 30-day granularity,
             starting Jan 1, 1970 all the way up to present, without having the aggregate name in the column names::
 
                 >>> df = client.time_series.data.retrieve_dataframe(
@@ -951,20 +971,22 @@ class DatapointsAPI(APIClient):
             ignore_unknown_ids=ignore_unknown_ids,
         )
         fetcher = select_dps_fetch_strategy(self, user_query=query)
-        if uniform_index:
-            grans_given = {q.granularity for q in fetcher.all_queries}
-            is_limited = any(q.limit is not None for q in fetcher.all_queries)
-            if fetcher.raw_queries or len(grans_given) > 1 or is_limited:
-                raise ValueError(
-                    "Cannot return a uniform index when asking for aggregates with multiple granularities "
-                    f"({grans_given}) OR when (partly) querying raw datapoints OR when a finite limit is used."
-                )
+        if not uniform_index:
+            return fetcher.fetch_all_datapoints_numpy().to_pandas(
+                column_names, include_aggregate_name, include_granularity_name
+            )
+        # Uniform index requires extra validation and processing:
+        grans_given = {q.granularity for q in fetcher.all_queries}
+        is_limited = any(q.limit is not None for q in fetcher.all_queries)
+        if fetcher.raw_queries or len(grans_given) > 1 or is_limited:
+            raise ValueError(
+                "Cannot return a uniform index when asking for aggregates with multiple granularities "
+                f"({grans_given}) OR when (partly) querying raw datapoints OR when a finite limit is used."
+            )
+
         df = fetcher.fetch_all_datapoints_numpy().to_pandas(
             column_names, include_aggregate_name, include_granularity_name
         )
-        if not uniform_index:
-            return df
-
         start = pd.Timestamp(min(q.start for q in fetcher.agg_queries), unit="ms")
         end = pd.Timestamp(max(q.end for q in fetcher.agg_queries), unit="ms")
         (granularity,) = grans_given
@@ -972,6 +994,171 @@ class DatapointsAPI(APIClient):
         freq = cast(str, granularity).replace("m", "T")
         return df.reindex(pd.date_range(start=start, end=end, freq=freq, inclusive="left"))
 
+    def retrieve_dataframe_in_tz(
+        self,
+        *,
+        id: int | Sequence[int] | None = None,
+        external_id: str | Sequence[str] | None = None,
+        start: datetime,
+        end: datetime,
+        aggregates: Sequence[str] | str | None = None,
+        granularity: Optional[str] = None,
+        ignore_unknown_ids: bool = False,
+        uniform_index: bool = False,
+        include_aggregate_name: bool = True,
+        include_granularity_name: bool = False,
+        column_names: Literal["id", "external_id"] = "external_id",
+    ) -> pd.DataFrame:
+        """Get datapoints directly in a pandas dataframe in the same time zone as start and end.
+
+        Note:
+            This is a convenience method. It builds on top of the methods ``retrieve_arrays`` and ``retrieve_dataframe``.
+            It enables you to get correct aggregates in your local time zone with daily, weekly, monthly, quarterly, and yearly
+            aggregates with automatic handling for daylight saving time (DST) transitions. If your time zone observes DST,
+            and your query crosses at least one DST-boundary, granularities like "3 days" or "1 week", that used to represent
+            fixed durations, no longer do so. To understand why, let's illustrate with an example: A typical time zone
+            that observes DST will skip one hour ahead during spring, leading to a day that is only 23 hours long, and oppositely
+            in the fall, turning back the clock one hour, yielding a 25-hour long day.
+
+        In short, this method works as follows:
+            1. Get the time zone from start and end (must be equal).
+            2. Split the time range from start to end into intervals based on DST boundaries.
+            3. Create a query for each interval and pass all to the retrieve_arrays method.
+            4. Stack the resulting arrays into a single column in the resulting DataFrame.
+
+        Warning:
+            The queries to ``retrieve_arrays`` are translated to a multiple of hours. This means that time zones that
+            are not a whole hour offset from UTC are not supported (yet). The same is true for time zones that observe
+            DST with an offset from standard time that is not a multiple of 1 hour.
+
+        Args:
+            id (int | Sequence[int] | None): ID or list of IDs.
+            external_id (str | Sequence[str] | None): External ID or list of External IDs.
+            start (datetime): Inclusive start, must be time zone aware.
+            end (datetime): Exclusive end, must be time zone aware and have the same time zone as start.
+            aggregates (str | list[str] | None): Single aggregate or list of aggregates to retrieve. Default: None (raw datapoints returned)
+            granularity (str): The granularity to fetch aggregates at, supported are: second, minute, hour, day, week, month, quarter and year. Default: None.
+            ignore_unknown_ids (bool): Whether to ignore missing time series rather than raising an exception. Default: False
+            uniform_index (bool): If querying aggregates, specifying `uniform_index=True` will return a dataframe with an
+                index with constant spacing between timestamps decided by granularity all the way from `start` to `end` (missing values will be NaNs). Default: False
+            include_aggregate_name (bool): Include 'aggregate' in the column name, e.g. `my-ts|average`. Ignored for raw time series. Default: True
+            include_granularity_name (bool): Include 'granularity' in the column name, e.g. `my-ts|12h`. Added after 'aggregate' when present. Ignored for raw time series. Default: False
+            column_names ("id" | "external_id"): Use either ids or external ids as column names. Time series missing external id will use id as backup. Default: "external_id"
+
+        Returns:
+            pandas.DataFrame: A pandas DataFrame containing the requested time series with a DatetimeIndex localized
+            in the given time zone.
+
+        Examples:
+
+            Get a pandas dataframe in the time zone of Oslo, Norway:
+
+                >>> from cognite.client import CogniteClient
+                >>> # In Python >=3.9 you may import directly from `zoneinfo`
+                >>> from cognite.client.utils import ZoneInfo
+                >>> client = CogniteClient()
+                >>> df = client.time_series.data.retrieve_dataframe_in_tz(
+                ...     id=12345,
+                ...     start=datetime(2023, 1, 1, tzinfo=ZoneInfo("Europe/Oslo")),
+                ...     end=datetime(2023, 2, 1, tzinfo=ZoneInfo("Europe/Oslo")),
+                ...     aggregates="average",
+                ...     granularity="1week",
+                ...     column_names="id")
+
+            Get a pandas dataframe with the sum and continuous variance of the time series with external id "foo" and "bar",
+            for each quarter from 2020 to 2022 returned in the time zone of Oslo, Norway:
+
+                >>> from cognite.client import CogniteClient
+                >>> # In Python >=3.9 you may import directly from `zoneinfo`
+                >>> from cognite.client.utils import ZoneInfo
+                >>> client = CogniteClient()
+                >>> df = client.time_series.data.retrieve_dataframe(
+                ...     external_id=["foo", "bar"],
+                ...     aggregates=["sum", "continuous_variance"],
+                ...     granularity="1quarter",
+                ...     start=datetime(2020, 1, 1, tzinfo=ZoneInfo("Europe/Oslo")),
+                ...     end=datetime(2022, 12, 31, tzinfo=ZoneInfo("Europe/Oslo")))
+
+        Tip:
+            You can also use shorter granularities such as second(s), minute(s), hour(s), which do not require
+            any special handling of DST. The longer granularities at your disposal, which are adjusted for DST, are:
+            day(s), week(s), month(s), quarter(s) and year(s). All the granularities support a one-letter version
+            ``s``, ``m``, ``h``, ``d``, ``w``, ``q``, and ``y``, except for month, to avoid confusion with minutes.
+            Furthermore, the granularity is expected to be given as a lowercase.
+        """
+        _, pd = local_import("numpy", "pandas")  # Verify that deps are available or raise CogniteImportError
+
+        if not exactly_one_is_not_none(id, external_id):
+            raise ValueError("Either input id(s) or external_id(s)")
+
+        if exactly_one_is_not_none(aggregates, granularity):
+            raise ValueError(
+                "Got only one of 'aggregates' and 'granularity'."
+                "Pass both to get aggregates, or neither to get raw data"
+            )
+
+        tz = validate_timezone(start, end)
+        if aggregates is None and granularity is None:
+            # Raw Data only need to convert the timezone
+            return (
+                self.retrieve_dataframe(
+                    id=id,
+                    external_id=external_id,
+                    start=start,
+                    end=end,
+                    aggregates=aggregates,
+                    granularity=granularity,
+                    ignore_unknown_ids=ignore_unknown_ids,
+                    uniform_index=uniform_index,
+                    include_aggregate_name=include_aggregate_name,
+                    include_granularity_name=include_granularity_name,
+                    column_names=column_names,
+                    limit=None,
+                )
+                .tz_localize("utc")
+                .tz_convert(tz.key)
+            )
+
+        assert isinstance(granularity, str)  # mypy
+
+        if in_timedelta(granularity) / timedelta(hours=1) > self._GRANULARITY_HOURS_LIMIT:
+            multiplier, unit = get_granularity_multiplier_and_unit(granularity)
+            days = _unit_in_days(unit)
+            limit = math.floor(timedelta(hours=self._GRANULARITY_HOURS_LIMIT) / timedelta(days=days))
+            raise ValueError(f"Granularity above the maximum limit, {limit} {unit}s.")
+
+        identifiers = IdentifierSequence.load(id, external_id)
+        if not identifiers.are_unique():
+            duplicated = find_duplicates(identifiers.as_primitives())
+            raise ValueError(f"The following identifiers were not unique: {duplicated}")
+
+        intervals = to_fixed_utc_intervals(start, end, granularity)
+
+        queries = [
+            {**ident_dct, "aggregates": aggregates, **interval}  # type: ignore [arg-type]
+            for ident_dct, interval in itertools.product(identifiers.as_dicts(), intervals)
+        ]
+
+        arrays = self.retrieve_arrays(
+            limit=None,
+            ignore_unknown_ids=ignore_unknown_ids,
+            **{identifiers[0].name(): queries},  # type: ignore [arg-type]
+        )
+        assert isinstance(arrays, DatapointsArrayList)  # mypy
+        arrays.concat_duplicate_ids()
+        df = (
+            arrays.to_pandas(column_names, include_aggregate_name, include_granularity_name)
+            .tz_localize("utc")
+            .tz_convert(tz.key)
+        )
+
+        if uniform_index:
+            freq = to_pandas_freq(granularity, start)
+            start, end = align_large_granularity(start, end, granularity)
+            return df.reindex(pandas_date_range_tz(start, end, freq, inclusive="left"))
+
+        return df
+
     def retrieve_latest(
         self,
         id: Union[int, LatestDatapointQuery, List[Union[int, LatestDatapointQuery]]] = None,
@@ -1283,8 +1470,9 @@ class DatapointsBin:
 
 
 class DatapointsPoster:
-    def __init__(self, client: DatapointsAPI) -> None:
-        self.client = client
+    def __init__(self, dps_client: DatapointsAPI) -> None:
+        self.dps_client = dps_client
+        self.limit = self.dps_client._DPS_INSERT_LIMIT
         self.bins: List[DatapointsBin] = []
 
     def insert(self, dps_object_list: List[Dict[str, Any]]) -> None:
@@ -1345,15 +1533,15 @@ class DatapointsPoster:
 
     def _bin_datapoints(self, dps_object_list: List[Dict[str, Any]]) -> List[List[Dict[str, Any]]]:
         for dps_object in dps_object_list:
-            for i in range(0, len(dps_object["datapoints"]), DPS_LIMIT):
+            for i in range(0, len(dps_object["datapoints"]), self.limit):
                 dps_object_chunk = {k: dps_object[k] for k in ["id", "externalId"] if k in dps_object}
-                dps_object_chunk["datapoints"] = dps_object["datapoints"][i : i + DPS_LIMIT]
+                dps_object_chunk["datapoints"] = dps_object["datapoints"][i : i + self.limit]
                 for bin in self.bins:
                     if bin.will_fit(len(dps_object_chunk["datapoints"])):
                         bin.add(dps_object_chunk)
                         break
                 else:
-                    bin = DatapointsBin(DPS_LIMIT, POST_DPS_OBJECTS_LIMIT)
+                    bin = DatapointsBin(self.limit, self.dps_client._POST_DPS_OBJECTS_LIMIT)
                     bin.add(dps_object_chunk)
                     self.bins.append(bin)
         binned_dps_object_list = []
@@ -1365,7 +1553,7 @@ class DatapointsPoster:
         tasks = []
         for dps_object_list in dps_object_lists:
             tasks.append((dps_object_list,))
-        summary = execute_tasks(self._insert_datapoints, tasks, max_workers=self.client._config.max_workers)
+        summary = execute_tasks(self._insert_datapoints, tasks, max_workers=self.dps_client._config.max_workers)
         summary.raise_compound_exception_if_failed_tasks(
             task_unwrap_fn=lambda x: x[0],
             task_list_element_unwrap_fn=lambda x: {k: x[k] for k in ["id", "externalId"] if k in x},
@@ -1375,7 +1563,7 @@ class DatapointsPoster:
         # convert to memory intensive format as late as possible and clean up after
         for it in post_dps_objects:
             it["datapoints"] = [{"timestamp": t, "value": v} for t, v in it["datapoints"]]
-        self.client._post(url_path=self.client._RESOURCE_PATH, json={"items": post_dps_objects})
+        self.dps_client._post(url_path=self.dps_client._RESOURCE_PATH, json={"items": post_dps_objects})
         for it in post_dps_objects:
             del it["datapoints"]
 
@@ -1459,7 +1647,7 @@ class RetrieveLatestDpsFetcher:
                 "url_path": self.dps_client._RESOURCE_PATH + "/latest",
                 "json": {"items": chunk, "ignoreUnknownIds": self.ignore_unknown_ids},
             }
-            for chunk in split_into_chunks(self._all_identifiers, RETRIEVE_LATEST_LIMIT)
+            for chunk in split_into_chunks(self._all_identifiers, self.dps_client._RETRIEVE_LATEST_LIMIT)
         ]
         tasks_summary = execute_tasks(self.dps_client._post, tasks, max_workers=self.dps_client._config.max_workers)
         if tasks_summary.exceptions:
