@@ -14,8 +14,8 @@ from zipfile import ZipFile
 
 from cognite.client import utils
 from cognite.client._api_client import APIClient
-from cognite.client._constants import LIST_LIMIT_CEILING, LIST_LIMIT_DEFAULT
-from cognite.client.credentials import APIKey, OAuthClientCertificate
+from cognite.client._constants import LIST_LIMIT_DEFAULT
+from cognite.client.credentials import OAuthClientCertificate
 from cognite.client.data_classes import (
     ClientCredentials,
     Function,
@@ -34,10 +34,12 @@ from cognite.client.data_classes.files import FileMetadata
 from cognite.client.data_classes.functions import FunctionCallsFilter, FunctionsStatus
 from cognite.client.exceptions import CogniteAuthError
 from cognite.client.utils._auxiliary import is_unlimited
-from cognite.client.utils._identifier import IdentifierSequence, SingletonIdentifierSequence
+from cognite.client.utils._identifier import Identifier, IdentifierSequence
 
 if TYPE_CHECKING:
     from cognite.client import CogniteClient
+    from cognite.client.config import ClientConfig
+
 
 HANDLER_FILE_NAME = "handler.py"
 MAX_RETRIES = 5
@@ -46,25 +48,23 @@ REQUIREMENTS_REG = re.compile(r"(\[\/?requirements\]){1}$", flags=re.M)  # Match
 UNCOMMENTED_LINE_REG = re.compile(r"^[^\#]]*.*")
 
 
-def _get_function_internal_id(_cognite_client: CogniteClient, identifier: SingletonIdentifierSequence) -> int:
-    id_object = identifier[0]
-    id_dict = id_object.as_dict()
+def _get_function_internal_id(cognite_client: CogniteClient, identifier: Identifier) -> int:
+    primitive = identifier.as_primitive()
+    if identifier.is_id:
+        return primitive
 
-    if "id" in id_dict:
-        return id_object.as_primitive()
-
-    if "externalId" in id_dict:
-        function = _cognite_client.functions.retrieve(external_id=id_object.as_primitive())
+    if identifier.is_external_id:
+        function = cognite_client.functions.retrieve(external_id=primitive)
         if function:
             return function.id
 
-    raise ValueError(f'Function with external ID "{id_object.as_primitive()}" is not found')
+    raise ValueError(f'Function with external ID "{primitive}" is not found')
 
 
-def _get_function_identifier(id: Optional[int], external_id: Optional[str]) -> SingletonIdentifierSequence:
-    identifier = IdentifierSequence.load(ids=id, external_ids=external_id)
+def _get_function_identifier(function_id: Optional[int], function_external_id: Optional[str]) -> Identifier:
+    identifier = IdentifierSequence.load(function_id, function_external_id, id_name="function")
     if identifier.is_singleton():
-        return identifier.as_singleton()
+        return identifier[0]
     raise AssertionError("Exactly one of function_id and function_external_id must be specified")
 
 
@@ -72,11 +72,12 @@ class FunctionsAPI(APIClient):
     _RESOURCE_PATH = "/functions"
     _LIST_CLASS = FunctionList
 
-    def __init__(self, *args: Any, **kwargs: Any) -> None:
-        super().__init__(*args, **kwargs)
-        self.calls = FunctionCallsAPI(*args, **kwargs)
-        self.schedules = FunctionSchedulesAPI(*args, **kwargs)
-        self._cognite_client: CogniteClient = cast("CogniteClient", self._cognite_client)
+    def __init__(self, config: ClientConfig, api_version: Optional[str], cognite_client: CogniteClient) -> None:
+        super().__init__(config, api_version, cognite_client)
+        self.calls = FunctionCallsAPI(config, api_version, cognite_client)
+        self.schedules = FunctionSchedulesAPI(config, api_version, cognite_client)
+        # Variable used to guarantee all items are returned when list(limit) is None, inf or -1.
+        self._LIST_LIMIT_CEILING = 10_000
 
     def create(
         self,
@@ -88,7 +89,6 @@ class FunctionsAPI(APIClient):
         external_id: Optional[str] = None,
         description: Optional[str] = "",
         owner: Optional[str] = "",
-        api_key: Optional[str] = None,
         secrets: Optional[Dict] = None,
         env_vars: Optional[Dict] = None,
         cpu: Optional[Number] = None,
@@ -106,8 +106,7 @@ class FunctionsAPI(APIClient):
 
         The function named `handle` is the entrypoint of the created function. Valid arguments to `handle` are `data`, `client`, `secrets` and `function_call_info`:\n
         - If the user calls the function with input data, this is passed through the `data` argument.\n
-        - If the user gives an `api_key` when creating the function, a pre instantiated CogniteClient is passed through the `client` argument.\n
-        - If the user gives one or more secrets when creating the function, these are passed through the `secrets` argument. The API key can be access through `secrets["apikey"]`.\n
+        - If the user gives one or more secrets when creating the function, these are passed through the `secrets` argument. \n
         - Data about the function call can be accessed via the argument `function_call_info`, which is a dictionary with keys `function_id` and, if the call is scheduled, `schedule_id` and `scheduled_time`.\n
 
         Args:
@@ -119,8 +118,7 @@ class FunctionsAPI(APIClient):
             external_id (str, optional):             External id of the function.
             description (str, optional):             Description of the function.
             owner (str, optional):                   Owner of this function. Typically used to know who created it.
-            api_key (str, optional):                 API key that can be used inside the function to access data in CDF.
-            secrets (Dict[str, str]):                Additional secrets as key/value pairs. These can e.g. password to simulators or other data sources. Keys must be lowercase characters, numbers or dashes (-) and at most 15 characters. You can create at most 30 secrets, all keys must be unique, and cannot be apikey.
+            secrets (Dict[str, str]):                Additional secrets as key/value pairs. These can e.g. password to simulators or other data sources. Keys must be lowercase characters, numbers or dashes (-) and at most 15 characters. You can create at most 30 secrets, all keys must be unique.
             env_vars (Dict[str, str]):               Environment variables as key/value pairs. Keys can contain only letters, numbers or the underscore character. You can create at most 100 environment variables.
             cpu (Number, optional):                  Number of CPU cores per function. Allowed values are in the range [0.1, 0.6], and None translates to the API default which is 0.25 in GCP. The argument is unavailable in Azure.
             memory (Number, optional):               Memory per function measured in GB. Allowed values are in the range [0.1, 2.5], and None translates to the API default which is 1 GB in GCP. The argument is unavailable in Azure.
@@ -209,8 +207,6 @@ class FunctionsAPI(APIClient):
             function["runtime"] = runtime
         if external_id:
             function["externalId"] = external_id
-        if api_key:
-            function["apiKey"] = api_key
         if secrets:
             function["secrets"] = secrets
         if extra_index_urls:
@@ -275,7 +271,7 @@ class FunctionsAPI(APIClient):
                 >>> functions_list = c.functions.list()
         """
         if is_unlimited(limit):
-            limit = LIST_LIMIT_CEILING
+            limit = self._LIST_LIMIT_CEILING
 
         filter = FunctionFilter(
             name=name,
@@ -385,7 +381,7 @@ class FunctionsAPI(APIClient):
                 >>> func = c.functions.retrieve(id=1)
                 >>> call = func.call()
         """
-        identifier = IdentifierSequence.load(ids=id, external_ids=external_id).as_singleton()
+        identifier = IdentifierSequence.load(ids=id, external_ids=external_id).as_singleton()[0]
         id = _get_function_internal_id(self._cognite_client, identifier)
         nonce = _create_session_and_return_nonce(self._cognite_client)
 
@@ -540,11 +536,8 @@ def _create_session_and_return_nonce(
     client_credentials: Union[Dict, ClientCredentials, None] = None,
 ) -> Optional[str]:
     if client_credentials is None:
-        if isinstance(client._config.credentials, APIKey):
-            return None
-        elif isinstance(client._config.credentials, OAuthClientCertificate):
+        if isinstance(client._config.credentials, OAuthClientCertificate):
             raise CogniteAuthError("Client certificate credentials is not supported with the Functions API")
-
     elif isinstance(client_credentials, dict):
         client_credentials = ClientCredentials(client_credentials["client_id"], client_credentials["client_secret"])
     return client.iam.sessions.create(client_credentials).nonce
@@ -856,6 +849,10 @@ class FunctionSchedulesAPI(APIClient):
     _RESOURCE_PATH = "/functions/schedules"
     _LIST_CLASS = FunctionSchedulesList
 
+    def __init__(self, config: ClientConfig, api_version: Optional[str], cognite_client: CogniteClient) -> None:
+        super().__init__(config, api_version, cognite_client)
+        self._LIST_LIMIT_CEILING = 10_000
+
     def retrieve(self, id: int) -> Union[FunctionSchedule, FunctionSchedulesList, None]:
         """`Retrieve a single function schedule by id. <https://docs.cognite.com/api/v1/#operation/byIdsFunctionSchedules>`_
 
@@ -924,7 +921,7 @@ class FunctionSchedulesAPI(APIClient):
                 raise AssertionError("Only function_id or function_external_id allowed when listing schedules.")
 
         if is_unlimited(limit):
-            limit = LIST_LIMIT_CEILING
+            limit = self._LIST_LIMIT_CEILING
 
         filter = FunctionSchedulesFilter(
             name=name,
