@@ -19,7 +19,8 @@ from cognite.client.data_classes.annotation_types.images import AssetLink, Objec
 from cognite.client.data_classes.annotation_types.primitives import VisionResource
 from cognite.client.data_classes.annotations import AnnotationList
 from cognite.client.exceptions import CogniteAPIError, CogniteException, ModelFailedException
-from cognite.client.utils._auxiliary import convert_true_match, exactly_one_is_not_none, to_snake_case
+from cognite.client.utils._auxiliary import convert_true_match, exactly_one_is_not_none
+from cognite.client.utils._text import to_snake_case
 
 if TYPE_CHECKING:
     import pandas
@@ -28,7 +29,7 @@ if TYPE_CHECKING:
 
 
 class JobStatus(Enum):
-    _NOT_STARTED = None
+    _NOT_STARTED: None = None
     QUEUED = "Queued"
     RUNNING = "Running"
     COMPLETED = "Completed"
@@ -799,7 +800,7 @@ class VisionExtractJob(VisionJob):
             Annotation(
                 annotated_resource_id=item.file_id,
                 annotation_type=VISION_ANNOTATION_TYPE_MAP[prediction_type],
-                data=data.dump(),
+                data=data,
                 annotated_resource_type="file",
                 status="suggested",
                 creating_app=creating_app or "cognite-sdk-python",
@@ -823,7 +824,7 @@ class VisionExtractJob(VisionJob):
         See https://docs.cognite.com/api/v1/#tag/Annotations/operation/annotationsSuggest
 
         Args:
-            creating_app (str, optional): The name of the app from which this annotation was created. Defaults to 'cognite-sdk-experimental'.
+            creating_app (str, optional): The name of the app from which this annotation was created. Defaults to 'cognite-sdk-python'.
             creating_app_version (str, optional): The version of the app that created this annotation. Must be a valid semantic versioning (SemVer) string. Defaults to client version.
             creating_user: (str, optional): A username, or email, or name. This is not checked nor enforced. If the value is None, it means the annotation was created by a service.
         Returns:
