@@ -4,7 +4,7 @@ import time
 from numbers import Number
 from typing import TYPE_CHECKING, Dict, List, Optional, Union, cast
 
-from cognite.client._constants import LIST_LIMIT_CEILING, LIST_LIMIT_DEFAULT
+from cognite.client._constants import LIST_LIMIT_DEFAULT
 from cognite.client.data_classes._base import CogniteFilter, CogniteResource, CogniteResourceList, CogniteResponse
 from cognite.client.data_classes.shared import TimestampRange
 from cognite.client.utils._auxiliary import is_unlimited
@@ -26,7 +26,6 @@ class Function(CogniteResource):
         file_id (int): File id of the code represented by this object.
         function_path (str): Relative path from the root folder to the file containing the `handle` function. Defaults to `handler.py`. Must be on posix path format.
         created_time (int): Created time in UNIX.
-        api_key (str): Api key attached to the function.
         secrets (Dict[str, str]): Secrets attached to the function ((key, value) pairs).
         env_vars (Dict[str, str]): User specified environment variables on the function ((key, value) pairs).
         cpu (Number): Number of CPU cores per function. Defaults to 0.25. Allowed values are in the range [0.1, 0.6].
@@ -49,7 +48,6 @@ class Function(CogniteResource):
         file_id: int = None,
         function_path: str = None,
         created_time: int = None,
-        api_key: str = None,
         secrets: Dict = None,
         env_vars: Dict = None,
         cpu: Number = None,
@@ -69,7 +67,6 @@ class Function(CogniteResource):
         self.file_id = file_id
         self.function_path = function_path
         self.created_time = created_time
-        self.api_key = api_key
         self.secrets = secrets
         self.env_vars = env_vars
         self.cpu = cpu
@@ -136,7 +133,7 @@ class Function(CogniteResource):
         schedules_by_id = self._cognite_client.functions.schedules.list(function_id=self.id, limit=limit)
 
         if is_unlimited(limit):
-            limit = LIST_LIMIT_CEILING
+            limit = self._cognite_client.functions.schedules._LIST_LIMIT_CEILING
 
         return (schedules_by_external_id + schedules_by_id)[:limit]
 
@@ -212,6 +209,7 @@ class FunctionSchedule(CogniteResource):
         cron_expression (str): Cron expression
         created_time (int): The number of milliseconds since 00:00:00 Thursday, 1 January 1970, Coordinated Universal Time (UTC), minus leap seconds.
         session_id (int): ID of the session running with the schedule.
+        when (str): When the schedule will trigger, in human readable text (server generated from cron_expression).
         cognite_client (CogniteClient): An optional CogniteClient to associate with this data class.
     """
 
@@ -225,6 +223,7 @@ class FunctionSchedule(CogniteResource):
         created_time: int = None,
         cron_expression: str = None,
         session_id: int = None,
+        when: str = None,
         cognite_client: CogniteClient = None,
     ) -> None:
         self.id = id
@@ -235,6 +234,7 @@ class FunctionSchedule(CogniteResource):
         self.cron_expression = cron_expression
         self.created_time = created_time
         self.session_id = session_id
+        self.when = when
         self._cognite_client = cast("CogniteClient", cognite_client)
 
     def get_input_data(self) -> Optional[dict]:
