@@ -4,6 +4,7 @@ import numbers
 from typing import Dict, Generic, Iterable, List, Optional, Sequence, Tuple, TypeVar, Union, cast, overload
 
 from cognite.client._constants import MAX_VALID_INTERNAL_ID
+from cognite.client.utils._auxiliary import split_into_chunks
 
 T_ID = TypeVar("T_ID", int, str)
 
@@ -31,24 +32,27 @@ class Identifier(Generic[T_ID]):
             return Identifier(external_id)
         raise ValueError("At least one of id and external id must be specified")
 
+    def name(self, camel_case: bool = False) -> str:
+        if isinstance(self.__value, int):
+            return "id"
+        return "externalId" if camel_case else "external_id"
+
     def as_primitive(self) -> T_ID:
         return self.__value
 
+    @property
+    def is_id(self) -> bool:
+        return isinstance(self.as_primitive(), int)
+
+    @property
+    def is_external_id(self) -> bool:
+        return isinstance(self.as_primitive(), str)
+
     def as_dict(self, camel_case: bool = True) -> Dict[str, T_ID]:
-        if isinstance(self.__value, str):
-            if camel_case:
-                return {"externalId": self.__value}
-            return {"external_id": self.__value}
-        else:
-            return {"id": self.__value}
+        return {self.name(camel_case): self.__value}
 
     def as_tuple(self, camel_case: bool = True) -> Tuple[str, T_ID]:
-        if isinstance(self.__value, str):
-            if camel_case:
-                return ("externalId", self.__value)
-            return ("external_id", self.__value)
-        else:
-            return ("id", self.__value)
+        return self.name(camel_case), self.__value
 
     def __str__(self) -> str:
         return repr(self)
@@ -91,8 +95,8 @@ class IdentifierSequence:
 
     def chunked(self, chunk_size: int) -> Iterable[IdentifierSequence]:
         return [
-            IdentifierSequence(self._identifiers[i : i + chunk_size], is_singleton=self.is_singleton())
-            for i in range(0, len(self), chunk_size)
+            IdentifierSequence(chunk, is_singleton=self.is_singleton())
+            for chunk in split_into_chunks(self._identifiers, chunk_size)
         ]
 
     def as_dicts(self) -> List[Dict[str, Union[int, str]]]:
@@ -101,6 +105,9 @@ class IdentifierSequence:
     def as_primitives(self) -> List[Union[int, str]]:
         return [identifier.as_primitive() for identifier in self._identifiers]
 
+    def are_unique(self) -> bool:
+        return len(self) == len(set(self.as_primitives()))
+
     @overload
     @classmethod
     def of(cls, *ids: List[Union[int, str]]) -> IdentifierSequence:
@@ -120,8 +127,14 @@ class IdentifierSequence:
 
     @classmethod
     def load(
-        cls, ids: Optional[Union[int, Sequence[int]]] = None, external_ids: Optional[Union[str, Sequence[str]]] = None
+        cls,
+        ids: Optional[Union[int, Sequence[int]]] = None,
+        external_ids: Optional[Union[str, Sequence[str]]] = None,
+        *,
+        id_name: str = "",
     ) -> IdentifierSequence:
+        if id_name and not id_name.endswith("_"):
+            id_name += "_"
         value_passed_as_primitive = False
         all_identifiers: List[Union[int, str]] = []
 
@@ -132,7 +145,7 @@ class IdentifierSequence:
             elif isinstance(ids, Sequence) and not isinstance(ids, str):
                 all_identifiers.extend([int(id_) for id_ in ids])
             else:
-                raise TypeError(f"ids must be of type int or Sequence[int]. Found {type(ids)}")
+                raise TypeError(f"{id_name}ids must be of type int or Sequence[int]. Found {type(ids)}")
 
         if external_ids is not None:
             if isinstance(external_ids, str):
@@ -141,7 +154,9 @@ class IdentifierSequence:
             elif isinstance(external_ids, Sequence):
                 all_identifiers.extend([str(extid) for extid in external_ids])
             else:
-                raise TypeError(f"external_ids must be of type str or Sequence[str]. Found {type(external_ids)}")
+                raise TypeError(
+                    f"{id_name}external_ids must be of type str or Sequence[str]. Found {type(external_ids)}"
+                )
 
         is_singleton = value_passed_as_primitive and len(all_identifiers) == 1
         return cls(identifiers=[Identifier(val) for val in all_identifiers], is_singleton=is_singleton)
